==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/dlm/kotlin/outputs/LifecyclePolicyPolicyDetailsActionCrossRegionCopy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dlm.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property encryptionConfiguration The encryption settings for the copied snapshot. See the `encryption_configuration` block. Max of 1 per action.
 * @property retainRule Specifies the retention rule for cross-Region snapshot copies. See the `retain_rule` block. Max of 1 per action.
 * @property target The target Region or the Amazon Resource Name (ARN) of the target Outpost for the snapshot copies.
 */
public data class LifecyclePolicyPolicyDetailsActionCrossRegionCopy(
    public val encryptionConfiguration:
    LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfiguration,
    public val retainRule: LifecyclePolicyPolicyDetailsActionCrossRegionCopyRetainRule? = null,
    public val target: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.dlm.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopy):
            LifecyclePolicyPolicyDetailsActionCrossRegionCopy =
            LifecyclePolicyPolicyDetailsActionCrossRegionCopy(
                encryptionConfiguration = javaType.encryptionConfiguration().let({ args0 ->
                    com.pulumi.aws.dlm.kotlin.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfiguration.Companion.toKotlin(args0)
                }),
                retainRule = javaType.retainRule().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.dlm.kotlin.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyRetainRule.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                target = javaType.target(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/dlm/kotlin/outputs/LifecyclePolicyPolicyDetailsActionCrossRegionCopy.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dlm.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property encryptionConfiguration The encryption settings for the copied snapshot. See the `encryption_configuration` block. Max of 1 per action.
 * @property retainRule
 * @property target
 */
public data class LifecyclePolicyPolicyDetailsActionCrossRegionCopy(
    public val encryptionConfiguration: LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfiguration,
    public val retainRule: LifecyclePolicyPolicyDetailsActionCrossRegionCopyRetainRule? = null,
    public val target: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.dlm.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopy): LifecyclePolicyPolicyDetailsActionCrossRegionCopy =
            LifecyclePolicyPolicyDetailsActionCrossRegionCopy(
                encryptionConfiguration = javaType.encryptionConfiguration().let({ args0 ->
                    com.pulumi.aws.dlm.kotlin.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfiguration.Companion.toKotlin(args0)
                }),
                retainRule = javaType.retainRule().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.dlm.kotlin.outputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyRetainRule.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                target = javaType.target(),
            )
    }
}
